# voila-plain
Very simple template for Voila.

This template removes the "page" view and eliminates superfluous margins and padding. It is designed for embedding a Voila app on a page with other things, such as in a [Dashboard app](https://github.com/timkpaine/dashboard). It is  similar in minimalism to the "Lab" view provided by default with voila.


[![](ss.png)]()